import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//redering svg tag from html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const update = data => { 
  //Declaring constants we are using
  const title = 'Albums sortis en fonction du genre et de la date';
  
  const xValue = function(d) { return d.date; }; //display dates on x axis
  const xAxisLabel = 'Date';
  
  const yValue = function(d) { return +d.nb_musique; }; //display salees value on y axis
  const yAxisLabel = 'Nombre de Musique';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  //center g in svg
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  // group the data: I want to draw one line per group
  var sumstat = d3.nest() // nest function allows to group the calculation per level of a factor
    .key(function(d) { return d.genre;})
    .entries(data);

  // Add X axis --> it is a date format
  const xScale = d3.scaleTime()
    .domain(d3.extent(data, xValue))
    .range([ 0, innerWidth ])
  	.nice();
  
  //creating xAxis  
  const xAxis = d3.axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  // Add Y axis
  const yScale = d3.scaleLinear()
    .domain([0, d3.max(data, yValue)])
    .range([ innerHeight, 0 ])
  	.nice();
  
  //creating yAxis  
  const yAxis = d3.axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  
	//Appending Y axis label to svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending X axis label to svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
   xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  // color palette
  var res = sumstat.map(function(d){ return d.key }) // list of group names
  var color = d3.scaleOrdinal()
    .domain(res)
    .range(['#e41a1c','#377eb8','#4daf4a','#984ea3','#ff7f00','#ffff33','#a65628','#f781bf','#999999'])

  //Appending title of graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title); 
  
  
  // Draw the line
  g.selectAll(".line")
      .data(sumstat)
      .enter()
      .append("path")
        .attr("fill", "none")
        .attr("stroke", function(d){ return color(d.key) })
        .attr("stroke-width", 1.5)
        .attr("d", function(d){
          return d3.line()
            .x(function(d) { return xScale(d.date); })
            .y(function(d) { return yScale(+d.nb_musique); })
            (d.values)
        })

};

/*d3.json("data2.json").then((data) => { 
  data.forEach(function(d){
    let date = new Date(d.date);
    d.date = date;
  });
  
  //Trier les dates par ordre croissant 
  	data.sort(function (a, b) {
            return d3['ascending'](
              +a.date,
              +b.date
            );
    })
  	update(data);
});*/

let newData = new Array();
d3.json("album.json").then((data) => { 
  
    data.forEach(function(d){
    
    
      
    let isPresent = false;
    let index = null;

    if (d.genre != '') {
    	if (d.dateRelease != null){

        let date = new Date(d.dateRelease);
      
        newData.forEach(function(dd){          
        	if(dd.genre === d.genre){
            if(dd.date.getFullYear() === date.getFullYear()){
              console.log("here");
              isPresent = true;
              index = dd.id;
            }
          }     
        });
        if(isPresent){
          newData[index].nb_musique = newData[index].nb_musique + 1;
        }
        else{
          newData.push({
                 "id": newData.length,
                 "genre": d.genre,
                 "date" : date,
                 "nb_musique" : 1
          }); 
        }
      }
    }
      
    
  });
  console.log(newData);  
  //Trier les dates par ordre croissant 
  	newData.sort(function (a, b) {
            return d3['ascending'](
              +a.date,
              +b.date
            );
    })
  	update(newData);
});
